# -*- coding: utf-8 -*-
from pyramid_oereb.standard.xtf_import.util import parse_string, parse_multilingual_text, parse_ref


class Document(object):

    TAG_TEXT_AT_WEB = 'TextImWeb'
    TAG_LAW_STATUS = 'Rechtsstatus'
    TAG_PUBLISHED_FROM = 'publiziertAb'
    TAG_TITLE = 'Titel'
    TAG_OFFICIAL_TITLE = 'OffiziellerTitel'
    TAG_ABBREVIATION = 'Abkuerzung'
    TAG_OFFICIAL_NUMBER = 'OffizielleNr'
    TAG_RESPONSIBLE_OFFICE = 'ZustaendigeStelle'

    def __init__(self, session, model):
        self._session = session
        self._model = model

    def parse(self, document, document_type):  # pragma: no cover
        instance = self._model(
            id=document.attrib['TID'],
            text_at_web=parse_multilingual_text(document, self.TAG_TEXT_AT_WEB),
            law_status=parse_string(document, self.TAG_LAW_STATUS),
            published_from=parse_string(document, self.TAG_PUBLISHED_FROM),
            document_type=document_type,
            title=parse_multilingual_text(document, self.TAG_TITLE),
            official_title=parse_multilingual_text(document, self.TAG_OFFICIAL_TITLE),
            abbreviation=parse_multilingual_text(document, self.TAG_ABBREVIATION),
            official_number=parse_string(document, self.TAG_OFFICIAL_NUMBER),
            office_id=parse_ref(document, self.TAG_RESPONSIBLE_OFFICE)
        )
        self._session.add(instance)



# -*- coding: utf-8 -*-

from geoalchemy2.elements import _SpatialElement

from pyramid_oereb.lib import b64
from pyramid_oereb.lib.records.image import ImageRecord
from pyramid_oereb.lib.sources import BaseDatabaseSource
from geoalchemy2.shape import to_shape

from pyramid_oereb.lib.sources.municipality import MunicipalityBaseSource


class DatabaseSource(BaseDatabaseSource, MunicipalityBaseSource):

    def read(self):
        """
        Central method to read a municipality by it's id_bfs identifier.
        """
        session = self._adapter_.get_session(self._key_)
        try:
            results = session.query(self._model_).all()

            self.records = list()
            for result in results:
                logo = ImageRecord(b64.decode(result.logo))
                self.records.append(self._record_class_(
                    result.fosnr,
                    result.name,
                    result.published,
                    logo,
                    geom=to_shape(result.geom).wkt if isinstance(
                        result.geom, _SpatialElement) else None,
                ))
        finally:
            session.close()
